@@ -4,6 +4,7 @@ import typing
 
 from opentelemetry import trace, _logs
 from opentelemetry._logs.severity import std_to_otel
+from opentelemetry.exporter.otlp.proto.http import Compression
 from opentelemetry.exporter.otlp.proto.http._log_exporter import OTLPLogExporter
 from opentelemetry.exporter.otlp.proto.http.trace_exporter import OTLPSpanExporter
 from opentelemetry.instrumentation.logging import LoggingInstrumentor
@@ -32,7 +33,7 @@ class H(object):
         self,
         project_id: str,
         integrations: typing.List[Integration] = None,
-        record_logs: bool = False,
+        record_logs: bool = True,
         otlp_endpoint: str = "",
     ):
         """
@@ -45,7 +46,7 @@ class H(object):
 
         :param project_id: a string that corresponds to the verbose id of your project from app.highlight.io/setup
         :param integrations: a list of Integrations that allow connecting with your framework, like Flask or Django.
-        :param record_logs: set True if you would like python logging to be recorded as part of the session.
+        :param record_logs: defaults to True. set False if you want to disable python logging recording.
         :param otlp_endpoint: set to a custom otlp destination
         :return: a configured H instance
         """
@@ -59,14 +60,28 @@ class H(object):
 
         self._trace_provider = TracerProvider()
         self._trace_provider.add_span_processor(
-            BatchSpanProcessor(OTLPSpanExporter(f"{self._otlp_endpoint}/v1/traces"))
+            BatchSpanProcessor(
+                OTLPSpanExporter(
+                    f"{self._otlp_endpoint}/v1/traces", compression=Compression.Gzip
+                ),
+                schedule_delay_millis=1000,
+                max_export_batch_size=64,
+                export_timeout_millis=5000,
+            )
         )
         trace.set_tracer_provider(self._trace_provider)
         self.tracer = trace.get_tracer(__name__)
 
         self._log_provider = LoggerProvider()
         self._log_provider.add_log_record_processor(
-            BatchLogRecordProcessor(OTLPLogExporter(f"{self._otlp_endpoint}/v1/logs"))
+            BatchLogRecordProcessor(
+                OTLPLogExporter(
+                    f"{self._otlp_endpoint}/v1/logs", compression=Compression.Gzip
+                ),
+                schedule_delay_millis=1000,
+                max_export_batch_size=64,
+                export_timeout_millis=5000,
+            )
         )
         _logs.set_logger_provider(self._log_provider)
         self.log = self._log_provider.get_logger(__name__)
